Round a value to a defined number of significant digits printing out trailing zeros, if applicable
pretty_signif(x, digits = 6, sci_range = 6, sci_sep = "e")A string with the value.
The number to round.
integer indicating the number of significant digits.
integer (or Inf) indicating when to switch to
scientific notation instead of floating point. Zero indicates always use
scientific; Inf indicates to never use scientific notation;
otherwise, scientific notation is used when abs(log10(x)) > sci_range.
The separator to use for scientific notation strings (typically this will be either "e" or "x10^" for computer- or human-readable output).
Values that are not standard numbers like Inf, NA, and
NaN are returned as "Inf", "NA", and NaN.
signif(), pretty_round().